# mzTab-M reference implementation and validation API.
# 
# This is the mzTab-M reference implementation and validation API service.
# 
# OpenAPI spec version: 2.0.0
# Contact: nils.hoffmann@isas.de
# Generated by: https://github.com/swagger-api/swagger-codegen.git


#' MzTab Class
#'
#' mzTab-M is intended as a reporting standard for quantitative results from metabolomics/lipodomics approaches.  This format is further intended to provide local LIMS systems as well as MS metabolomics repositories a simple way to share and combine basic information.  The mzTab-M format consists of four cross-referenced data tables:          * Metadata (MTD),      * Small Molecule (SML),      * Small Molecule Feature (SMF) and the      * Small Molecule Evidence (SME).   The MTD and SML tables are mandatory, and for a file to contain any evidence about how molecules were quantified or identified by software, then all four tables must be present. The tables must follow the order MTD, SML, SMF and SME, with a blank line separating each table.   The structure of each table, in terms of the rows and columns that must be present is tightly specified and formally defined and explained in the mzTab-M specification document. mzTab-M files MUST have one Metadata (MTD) section and one Small Molecule (SML) Section. In practice, we expect that most files SHOULD also include one Small Molecule Feature (SMF) section, and one Small Molecule Evidence (SME) Section.  Files lacking SMF and SME sections can only present summary data about quantified molecules, without any evidence trail for how those values were derived. It will be left to reading software to determine whether additional validation will be requested such that SMF and SME tables MUST be present. 
#'
#' @field metadata 
#' @field smallMoleculeSummary 
#' @field smallMoleculeFeature 
#' @field smallMoleculeEvidence 
#' @field comment 
#'
#' 
#'
#' @importFrom R6 R6Class
#' @importFrom jsonlite fromJSON toJSON
#' @export
MzTab <- R6::R6Class(
  'MzTab',
  public = list(
    `metadata` = NULL,
    `smallMoleculeSummary` = NULL,
    `smallMoleculeFeature` = NULL,
    `smallMoleculeEvidence` = NULL,
    `comment` = NULL,
    initialize = function(`metadata`, `smallMoleculeSummary`, `smallMoleculeFeature`, `smallMoleculeEvidence`, `comment`){
      if (!missing(`metadata`)) {
        stopifnot(R6::is.R6(`metadata`))
        self$`metadata` <- `metadata`
      }
      if (!missing(`smallMoleculeSummary`)) {
        stopifnot(is.list(`smallMoleculeSummary`), length(`smallMoleculeSummary`) != 0)
        lapply(`smallMoleculeSummary`, function(x) stopifnot(R6::is.R6(x)))
        self$`smallMoleculeSummary` <- `smallMoleculeSummary`
      }
      if (!missing(`smallMoleculeFeature`)) {
        stopifnot(is.list(`smallMoleculeFeature`), length(`smallMoleculeFeature`) != 0)
        lapply(`smallMoleculeFeature`, function(x) stopifnot(R6::is.R6(x)))
        self$`smallMoleculeFeature` <- `smallMoleculeFeature`
      }
      if (!missing(`smallMoleculeEvidence`)) {
        stopifnot(is.list(`smallMoleculeEvidence`), length(`smallMoleculeEvidence`) != 0)
        lapply(`smallMoleculeEvidence`, function(x) stopifnot(R6::is.R6(x)))
        self$`smallMoleculeEvidence` <- `smallMoleculeEvidence`
      }
      if (!missing(`comment`)) {
        stopifnot(is.list(`comment`), length(`comment`) != 0)
        lapply(`comment`, function(x) stopifnot(R6::is.R6(x)))
        self$`comment` <- `comment`
      }
    },
    toJSON = function() {
      MzTabObject <- list()
      if (!is.null(self$`metadata`)) {
        MzTabObject[['metadata']] <- self$`metadata`$toJSON()
      }
      if (!is.null(self$`smallMoleculeSummary`)) {
        MzTabObject[['smallMoleculeSummary']] <- lapply(self$`smallMoleculeSummary`, function(x) x$toJSON())
      }
      if (!is.null(self$`smallMoleculeFeature`)) {
        MzTabObject[['smallMoleculeFeature']] <- lapply(self$`smallMoleculeFeature`, function(x) x$toJSON())
      }
      if (!is.null(self$`smallMoleculeEvidence`)) {
        MzTabObject[['smallMoleculeEvidence']] <- lapply(self$`smallMoleculeEvidence`, function(x) x$toJSON())
      }
      if (!is.null(self$`comment`)) {
        MzTabObject[['comment']] <- lapply(self$`comment`, function(x) x$toJSON())
      }

      MzTabObject
    },
    fromJSON = function(MzTabJson) {
      MzTabObject <- jsonlite::fromJSON(MzTabJson, simplifyVector = FALSE)
      if (!is.null(MzTabObject$`metadata`)) {
        `metadataObject` <- Metadata$new()
        `metadataObject`$fromJSON(jsonlite::toJSON(MzTabObject$metadata, auto_unbox = TRUE))
        self$`metadata` <- `metadataObject`
      }
      if (!is.null(MzTabObject$`smallMoleculeSummary`)) {
        self$`smallMoleculeSummary` <- lapply(MzTabObject$`smallMoleculeSummary`, function(x) {
          `smallMoleculeSummaryObject` <- SmallMoleculeSummary$new()
          `smallMoleculeSummaryObject`$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE))
          `smallMoleculeSummaryObject`
        })
      }
      if (!is.null(MzTabObject$`smallMoleculeFeature`)) {
        self$`smallMoleculeFeature` <- lapply(MzTabObject$`smallMoleculeFeature`, function(x) {
          `smallMoleculeFeatureObject` <- SmallMoleculeFeature$new()
          `smallMoleculeFeatureObject`$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE))
          `smallMoleculeFeatureObject`
        })
      }
      if (!is.null(MzTabObject$`smallMoleculeEvidence`)) {
        self$`smallMoleculeEvidence` <- lapply(MzTabObject$`smallMoleculeEvidence`, function(x) {
          `smallMoleculeEvidenceObject` <- SmallMoleculeEvidence$new()
          `smallMoleculeEvidenceObject`$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE))
          `smallMoleculeEvidenceObject`
        })
      }
      if (!is.null(MzTabObject$`comment`)) {
        self$`comment` <- lapply(MzTabObject$`comment`, function(x) {
          `commentObject` <- Comment$new()
          `commentObject`$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE))
          `commentObject`
        })
      }
    },
    toJSONString = function() {
       sprintf(
        '{
           "metadata": %s,
           "smallMoleculeSummary": [%s],
           "smallMoleculeFeature": [%s],
           "smallMoleculeEvidence": [%s],
           "comment": [%s]
        }',
        self$`metadata`$toJSON(),
        lapply(self$`smallMoleculeSummary`, function(x) paste(x$toJSON(), sep=",")),
        lapply(self$`smallMoleculeFeature`, function(x) paste(x$toJSON(), sep=",")),
        lapply(self$`smallMoleculeEvidence`, function(x) paste(x$toJSON(), sep=",")),
        lapply(self$`comment`, function(x) paste(x$toJSON(), sep=","))
      )
    },
    fromJSONString = function(MzTabJson) {
      MzTabObject <- jsonlite::fromJSON(MzTabJson, simplifyVector = FALSE)
      MetadataObject <- Metadata$new()
      self$`metadata` <- MetadataObject$fromJSON(jsonlite::toJSON(MzTabObject$metadata, auto_unbox = TRUE))
      self$`smallMoleculeSummary` <- lapply(MzTabObject$`smallMoleculeSummary`, function(x) SmallMoleculeSummary$new()$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE)))
      self$`smallMoleculeFeature` <- lapply(MzTabObject$`smallMoleculeFeature`, function(x) SmallMoleculeFeature$new()$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE)))
      self$`smallMoleculeEvidence` <- lapply(MzTabObject$`smallMoleculeEvidence`, function(x) SmallMoleculeEvidence$new()$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE)))
      self$`comment` <- lapply(MzTabObject$`comment`, function(x) Comment$new()$fromJSON(jsonlite::toJSON(x, auto_unbox = TRUE)))
    }
  )
)
